
CHANGES
=======


v0.0.1
------

*Release date: 2016-04-23*

- Optimized the ``copy`` method of frozen (immutable) dictionaries: without update arguments ``copy`` returns ``self``.


v0.0.0-beta
-----------

*Release date: 2016-04-19*

Initial release on pypi.
